export const COLORS: Readonly<{
    /**
     * The main gray color object.
     *
     * @deprecated Use semantic aliases in `COLORS.ui` or theme-ready variables in `COLORS.theme.gray`.
     */
    gray: {
        900: string;
        800: string;
        /** Meets 4.6:1 text contrast against white. */
        700: string;
        /** Meets 3:1 UI or large text contrast against white. */
        600: string;
        400: string;
        /** Used for most borders. */
        300: string;
        /** Used sparingly for light borders. */
        200: string;
        /** Used for light gray backgrounds. */
        100: string;
    };
    /**
     * @deprecated Prefer theme-ready variables in `COLORS.theme`.
     */
    white: "#fff";
    alert: {
        yellow: string;
        red: string;
        green: string;
    };
    /**
     * Theme-ready variables with fallbacks.
     *
     * Prefer semantic aliases in `COLORS.ui` when applicable.
     */
    theme: {
        accent: string;
        accentDarker10: string;
        accentDarker20: string;
        /** Used when placing text on the accent color. */
        accentInverted: string;
        background: string;
        foreground: string;
        /** Used when placing text on the foreground color. */
        foregroundInverted: string;
        gray: {
            /** @deprecated Use `COLORS.theme.foreground` instead. */
            900: string;
            800: string;
            700: string;
            600: string;
            400: string;
            300: string;
            200: string;
            100: string;
        };
    };
    /**
     * Semantic aliases (prefer these over raw variables when applicable).
     */
    ui: {
        background: string;
        backgroundDisabled: string;
        border: string;
        borderHover: string;
        borderFocus: string;
        borderDisabled: string;
        textDisabled: string;
        darkGrayPlaceholder: string;
        lightGrayPlaceholder: string;
    };
}>;
export default COLORS;
//# sourceMappingURL=colors-values.d.ts.map